@@ -5,4 +5,4 @@ Extractors
 Extractors are a way to build structured datasets that you can use from tags within Documents
 
 """
-from .extractors import *
+from .extractors import TaggedTableToDataStore
