@@ -1,6 +1,7 @@
 import dataclasses
 import itertools
 import json
+import os
 import re
 import uuid
 from enum import Enum
@@ -1417,6 +1418,7 @@ class Document(object):
         file_document.metadata.connector = 'file-handle'
         file_document.metadata.connector_options.file = file
         file_document.source.connector = 'file-handle'
+        file_document.source.original_filename = os.path.basename(file)
         file_document.source.original_path = file
         return file_document
 
@@ -1438,11 +1440,14 @@ class Document(object):
         url_document.metadata.connector_options.url = url
         url_document.metadata.connector_options.headers = headers
         url_document.source.connector = 'url'
+        import base64
+        encoded_url = base64.b64encode(url.encode('ascii'))
+        url_document.source.original_filename = encoded_url.decode('ascii')
         url_document.source.original_path = url
         url_document.source.headers = headers
         return url_document
 
-    def select(self, selector, variables={}):
+    def select(self, selector, variables=None):
         """
         Execute a selector on the root node and then return a list of the matching nodes.
 
@@ -1456,6 +1461,8 @@ class Document(object):
         :return: A list of the matching ContentNodes.  If no matches found, list is empty.
         :rtype: list[ContentNodes]
         """
+        if variables is None:
+            variables = {}
         if self.content_node:
             result = self.content_node.select(selector, variables)
             if isinstance(result, list):
@@ -1465,7 +1472,7 @@ class Document(object):
         else:
             return []
 
-    def select_as_node(self, selector, variables={}):
+    def select_as_node(self, selector, variables=None):
         """
         Execute a selector on the root node and then return new ContentNode with the results set as its children.
 
@@ -1479,6 +1486,8 @@ class Document(object):
         :return: A new ContentNode.  All ContentNodes on this Document that match the selector value are added as the children for the returned ContentNode.
         :rtype: ContentNode
         """
+        if variables is None:
+            variables = {}
         if self.content_node:
             return self.content_node.select_as_node(selector, variables)
         else:
