@@ -1,4 +1,21 @@
 from kodexa import Document
+from kodexa.stores.stores import DocumentStore
+
+
+class DocumentStoreSink:
+    """
+    A sink that writes to the underlying store
+    """
+
+    def __init__(self, document_store: DocumentStore):
+        self.document_store = document_store
+
+    @staticmethod
+    def get_name():
+        return "Store Sink"
+
+    def sink(self, document: Document):
+        self.document_store.put(document.uuid, document)
 
 
 class FolderSink:
